# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/intraday/v2/get_intraday_scalar.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.type import datetime_pb2 as google_dot_type_dot_datetime__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from systemathics.apis.type.shared.v1 import asset_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_asset__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import date_interval_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_date__interval__pb2
from systemathics.apis.type.shared.v1 import sampling_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_sampling__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@systemathics/apis/services/intraday/v2/get_intraday_scalar.proto\x12&systemathics.apis.services.intraday.v2\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1agoogle/type/datetime.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a,systemathics/apis/type/shared/v1/asset.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x34systemathics/apis/type/shared/v1/date_interval.proto\x1a/systemathics/apis/type/shared/v1/sampling.proto\"\xba\x02\n\x15IntradayScalarRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x16\n\x06\x66ields\x18\x02 \x03(\tR\x06\x66ields\x12\x46\n\x08sampling\x18\x03 \x01(\x0e\x32*.systemathics.apis.type.shared.v1.SamplingR\x08sampling\x12S\n\rdate_interval\x18\x04 \x01(\x0b\x32..systemathics.apis.type.shared.v1.DateIntervalR\x0c\x64\x61teInterval\x12\x1e\n\nadjustment\x18\x05 \x01(\x08R\nadjustment\"\xdb\x01\n\x1cIntradayScalarStreamResponse\x12X\n\x04info\x18\x01 \x01(\x0b\x32\x42.systemathics.apis.services.intraday.v2.IntradayScalarStreamFieldsH\x00R\x04info\x12V\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32@.systemathics.apis.services.intraday.v2.IntradayScalarStreamItemH\x00R\x04\x64\x61taB\t\n\x07payload\"4\n\x1aIntradayScalarStreamFields\x12\x16\n\x06\x66ields\x18\x01 \x03(\tR\x06\x66ields\"a\n\x18IntradayScalarStreamItem\x12\x31\n\x08\x64\x61tetime\x18\x01 \x01(\x0b\x32\x15.google.type.DateTimeR\x08\x64\x61tetime\x12\x12\n\x04\x64\x61ta\x18\x02 \x03(\x01R\x04\x64\x61ta\"\x8a\x01\n#IntradayScalarAssetProviderResponse\x12\x63\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32O.systemathics.apis.services.intraday.v2.IntradayScalarAssetProviderItemResponseR\x04\x64\x61ta\"\x91\x01\n\'IntradayScalarAssetProviderItemResponse\x12J\n\nasset_type\x18\x01 \x01(\x0e\x32+.systemathics.apis.type.shared.v1.AssetTypeR\tassetType\x12\x1a\n\x08provider\x18\x02 \x01(\tR\x08provider\"|\n\x1cIntradayScalarFieldsResponse\x12\\\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32H.systemathics.apis.services.intraday.v2.IntradayScalarFieldsItemResponseR\x04\x64\x61ta\"\xa2\x01\n IntradayScalarFieldsItemResponse\x12J\n\nasset_type\x18\x01 \x01(\x0e\x32+.systemathics.apis.type.shared.v1.AssetTypeR\tassetType\x12\x1a\n\x08provider\x18\x02 \x01(\tR\x08provider\x12\x16\n\x06\x66ields\x18\x03 \x03(\tR\x06\x66ields2\xa4\x04\n\x15IntradayScalarService\x12\xc2\x01\n\x14IntradayScalarStream\x12=.systemathics.apis.services.intraday.v2.IntradayScalarRequest\x1a\x44.systemathics.apis.services.intraday.v2.IntradayScalarStreamResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v2/intraday_scalar_stream/0\x01\x12\x99\x01\n\x14IntradayScalarFields\x12\x16.google.protobuf.Empty\x1a\x44.systemathics.apis.services.intraday.v2.IntradayScalarFieldsResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v2/intraday_scalar_fields/\x12\xa9\x01\n\x1bIntradayScalarAssetProvider\x12\x16.google.protobuf.Empty\x1aK.systemathics.apis.services.intraday.v2.IntradayScalarAssetProviderResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/v2/intraday_scalar_provider/B\x81\x02\n*com.systemathics.apis.services.intraday.v2B\x16GetIntradayScalarProtoP\x01\xa2\x02\x04SASI\xaa\x02&Systemathics.Apis.Services.Intraday.V2\xca\x02&Systemathics\\Apis\\Services\\Intraday\\V2\xe2\x02\x32Systemathics\\Apis\\Services\\Intraday\\V2\\GPBMetadata\xea\x02*Systemathics::Apis::Services::Intraday::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.intraday.v2.get_intraday_scalar_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n*com.systemathics.apis.services.intraday.v2B\026GetIntradayScalarProtoP\001\242\002\004SASI\252\002&Systemathics.Apis.Services.Intraday.V2\312\002&Systemathics\\Apis\\Services\\Intraday\\V2\342\0022Systemathics\\Apis\\Services\\Intraday\\V2\\GPBMetadata\352\002*Systemathics::Apis::Services::Intraday::V2'
  _globals['_INTRADAYSCALARSERVICE'].methods_by_name['IntradayScalarStream']._options = None
  _globals['_INTRADAYSCALARSERVICE'].methods_by_name['IntradayScalarStream']._serialized_options = b'\202\323\344\223\002\035\022\033/v2/intraday_scalar_stream/'
  _globals['_INTRADAYSCALARSERVICE'].methods_by_name['IntradayScalarFields']._options = None
  _globals['_INTRADAYSCALARSERVICE'].methods_by_name['IntradayScalarFields']._serialized_options = b'\202\323\344\223\002\035\022\033/v2/intraday_scalar_fields/'
  _globals['_INTRADAYSCALARSERVICE'].methods_by_name['IntradayScalarAssetProvider']._options = None
  _globals['_INTRADAYSCALARSERVICE'].methods_by_name['IntradayScalarAssetProvider']._serialized_options = b'\202\323\344\223\002\037\022\035/v2/intraday_scalar_provider/'
  _globals['_INTRADAYSCALARREQUEST']._serialized_start=426
  _globals['_INTRADAYSCALARREQUEST']._serialized_end=740
  _globals['_INTRADAYSCALARSTREAMRESPONSE']._serialized_start=743
  _globals['_INTRADAYSCALARSTREAMRESPONSE']._serialized_end=962
  _globals['_INTRADAYSCALARSTREAMFIELDS']._serialized_start=964
  _globals['_INTRADAYSCALARSTREAMFIELDS']._serialized_end=1016
  _globals['_INTRADAYSCALARSTREAMITEM']._serialized_start=1018
  _globals['_INTRADAYSCALARSTREAMITEM']._serialized_end=1115
  _globals['_INTRADAYSCALARASSETPROVIDERRESPONSE']._serialized_start=1118
  _globals['_INTRADAYSCALARASSETPROVIDERRESPONSE']._serialized_end=1256
  _globals['_INTRADAYSCALARASSETPROVIDERITEMRESPONSE']._serialized_start=1259
  _globals['_INTRADAYSCALARASSETPROVIDERITEMRESPONSE']._serialized_end=1404
  _globals['_INTRADAYSCALARFIELDSRESPONSE']._serialized_start=1406
  _globals['_INTRADAYSCALARFIELDSRESPONSE']._serialized_end=1530
  _globals['_INTRADAYSCALARFIELDSITEMRESPONSE']._serialized_start=1533
  _globals['_INTRADAYSCALARFIELDSITEMRESPONSE']._serialized_end=1695
  _globals['_INTRADAYSCALARSERVICE']._serialized_start=1698
  _globals['_INTRADAYSCALARSERVICE']._serialized_end=2246
# @@protoc_insertion_point(module_scope)
